# fns ![Release](https://github.com/amitness/fns/workflows/Release/badge.svg) [![Downloads](https://pepy.tech/badge/fns/month)](https://pepy.tech/project/fns) [![Version](https://img.shields.io/pypi/v/fns)](https://pypi.org/project/fns/) ![](https://img.shields.io/github/license/amitness/fns) ![](https://img.shields.io/pypi/pyversions/fns)
Reusable functions for Machine Learning.


## Installation
Install via [pip](https://pypi.org/project/fns).

```bash
pip install fns
```

## Documentation
The documentation is available [here](https://amitness.com/fns/).
